@@ -1,8 +1,8 @@
 from datetime import datetime
 from typing import Any, Callable
 
-from turbulette.core.errors import ErrorCode, add_error
-from turbulette.core.utils import is_query
+from turbulette.errors import ErrorCode, add_error
+from turbulette.utils import is_query
 
 from .core import TokenType, decode_jwt, process_jwt_header, settings
 from .exceptions import JWTInvalidTokenType, JWTNotFresh
@@ -25,9 +25,9 @@ def scope_required(func: Callable[..., Any]):
         if await authorized(claims, info):
             return await func(obj, info, claims, **kwargs)
         if is_query(info):
-            add_error("scope", ErrorCode.QUERY_NOT_ALLOWED)
+            add_error("policy", ErrorCode.QUERY_NOT_ALLOWED)
             return None
-        add_error("scope", ErrorCode.FIELD_NOT_ALLOWED, info.field_name)
+        add_error("policy", ErrorCode.FIELD_NOT_ALLOWED, info.field_name)
         return None
 
     return wrapper
