@@ -1,3 +1,6 @@
+# Locations
+PROJECT_SETTINGS_MODULE = "TURBULETTE_SETTINGS_MODULE"
+
 # Settings needed by turbulette
 SETTINGS_RULES = "SETTINGS_RULES"
 SETTINGS_LOGS = "CONFIGURE_LOGGING"
@@ -5,6 +8,7 @@ SETTINGS_INSTALLED_APPS = "INSTALLED_APPS"
 SETTINGS_DATABASE_SETTINGS = "DATABASE_SETTINGS"
 SETTINGS_DATABASE_CONNECTION = "DATABASE_CONNECTION"
 SETTINGS_DB_DSN = "DB_DSN"
+SETTINGS_MIDDLEWARES = "MIDDLEWARES"
 
 # Special settings needed by turbulette
 # see `simple_settings` documentation :
@@ -14,9 +18,6 @@ REQUIRED_SETTINGS_TYPES = "REQUIRED_SETTINGS_TYPES"
 REQUIRED_NOT_NONE_SETTINGS = "REQUIRED_NOT_NONE_SETTINGS"
 OVERRIDE_BY_ENV = "OVERRIDE_BY_ENV"
 
-# Env variables
-ENV_TURBULETTE_SETTINGS = "TURBULETTE_SETTINGS"
-
 # Files and folders
 FILE_ALEMBIC_INI = "alembic.ini"
 FOLDER_ALEMBIC = "alembic"
