@@ -1,13 +1,14 @@
 from importlib import import_module
 from pathlib import Path
-from typing import List
+from typing import List, Type
 from simple_settings.utils import SettingsStub
 from starlette.config import Config
+
 from .exceptions import ImproperlyConfigured
 
 
 def get_config_from_paths(paths: List[str]) -> Config:
-    """Return a Config instance from the first existing path
+    """Return a Config instance from the first existing path.
 
     Args:
         paths (List[str]): Paths to config file to try
@@ -26,22 +27,26 @@ def get_config_from_paths(paths: List[str]) -> Config:
 
 
 class TurubuletteSettingsStub(SettingsStub):
-    """Subclass of SettingsStub to make it work with Turbulette settings
+    """Subclass of SettingsStub to make it work with Turbulette settings.
 
-        Useful to safely change settings on the fly during tests
+    Useful to safely change settings on the fly during tests
     """
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         # Need to import here to make sure settings are initialized
         self.settings = getattr(import_module("turbulette.conf"), "settings")
+        self.old_settings = None
 
     def __enter__(self):
+        """Replace the corresponding Turbulette settings."""
         self.settings.setup()
         self.old_settings = self.settings.as_dict()
         self.settings.configure(**self.new_settings)
 
     def __exit__(self, ext_type, exc_value, traceback):
+        """Restore old settings."""
         self.settings.configure(**self.old_settings)
 
 
-settings_stub = TurubuletteSettingsStub
+settings_stub: Type[TurubuletteSettingsStub] = TurubuletteSettingsStub
